@@ -15,11 +15,12 @@
 
 import mock
 import netaddr
+from neutron_lib import exceptions
 import testtools
 
 from neutron.agent.common import utils  # noqa
 from neutron.agent.linux import ip_lib
-from neutron.common import exceptions
+from neutron.common import exceptions as n_exc
 from neutron.tests import base
 
 NETNS_SAMPLE = [
@@ -291,25 +292,8 @@ class TestIpWrapper(base.BaseTestCase):
         self.assertEqual(device_name, somedevice.name)
         self.assertFalse(devices)
 
-    @mock.patch('neutron.agent.common.utils.execute')
-    def test_get_devices_namespaces_ns_not_exists(self, mocked_execute):
-        mocked_execute.side_effect = RuntimeError(
-            "Cannot open network namespace")
-        with mock.patch.object(ip_lib.IpNetnsCommand, 'exists',
-                               return_value=False):
-            retval = ip_lib.IPWrapper(namespace='foo').get_devices()
-            self.assertEqual([], retval)
-
-    @mock.patch('neutron.agent.common.utils.execute')
-    def test_get_devices_namespaces_ns_exists(self, mocked_execute):
-        mocked_execute.side_effect = RuntimeError(
-            "Cannot open network namespace")
-        with mock.patch.object(ip_lib.IpNetnsCommand, 'exists',
-                               return_value=True):
-            self.assertRaises(RuntimeError,
-                              ip_lib.IPWrapper(namespace='foo').get_devices)
-
-    def test_get_namespaces(self):
+    def test_get_namespaces_non_root(self):
+        self.config(group='AGENT', use_helper_for_ns_read=False)
         self.execute.return_value = '\n'.join(NETNS_SAMPLE)
         retval = ip_lib.IPWrapper.get_namespaces()
         self.assertEqual(retval,
@@ -317,9 +301,11 @@ class TestIpWrapper(base.BaseTestCase):
                           'bbbbbbbb-bbbb-bbbb-bbbb-bbbbbbbbbbbb',
                           'cccccccc-cccc-cccc-cccc-cccccccccccc'])
 
-        self.execute.assert_called_once_with([], 'netns', ('list',))
+        self.execute.assert_called_once_with([], 'netns', ('list',),
+                                             run_as_root=False)
 
-    def test_get_namespaces_iproute2_4(self):
+    def test_get_namespaces_iproute2_4_root(self):
+        self.config(group='AGENT', use_helper_for_ns_read=True)
         self.execute.return_value = '\n'.join(NETNS_SAMPLE_IPROUTE2_4)
         retval = ip_lib.IPWrapper.get_namespaces()
         self.assertEqual(retval,
@@ -327,7 +313,8 @@ class TestIpWrapper(base.BaseTestCase):
                           'bbbbbbbb-bbbb-bbbb-bbbb-bbbbbbbbbbbb',
                           'cccccccc-cccc-cccc-cccc-cccccccccccc'])
 
-        self.execute.assert_called_once_with([], 'netns', ('list',))
+        self.execute.assert_called_once_with([], 'netns', ('list',),
+                                             run_as_root=True)
 
     def test_add_tuntap(self):
         ip_lib.IPWrapper().add_tuntap('tap0')
@@ -504,7 +491,7 @@ class TestIpWrapper(base.BaseTestCase):
 
     def test_add_vxlan_invalid_port_length(self):
         wrapper = ip_lib.IPWrapper()
-        self.assertRaises(exceptions.NetworkVxlanPortRangeError,
+        self.assertRaises(n_exc.NetworkVxlanPortRangeError,
                           wrapper.add_vxlan, 'vxlan0', 'vni0', group='group0',
                           dev='dev0', ttl='ttl0', tos='tos0',
                           local='local0', proxy=True,
@@ -994,42 +981,6 @@ class TestIpRouteCommand(TestIPCmdBase):
             self.assertEqual(self.route_cmd.get_gateway(),
                              test_case['expected'])
 
-    def test_pullup_route(self):
-        # NOTE(brian-haley) Currently we do not have any IPv6-specific usecase
-        # for pullup_route, hence skipping. Revisit, if required, in future.
-        if self.ip_version == 6:
-            return
-        # interface is not the first in the list - requires
-        # deleting and creating existing entries
-        output = [DEVICE_ROUTE_SAMPLE, SUBNET_SAMPLE1]
-
-        def pullup_side_effect(self, *args):
-            result = output.pop(0)
-            return result
-
-        self.parent._run = mock.Mock(side_effect=pullup_side_effect)
-        self.route_cmd.pullup_route('tap1d7888a7-10', ip_version=4)
-        self._assert_sudo([4], ('del', '10.0.0.0/24', 'dev', 'qr-23380d11-d2'))
-        self._assert_sudo([4], ('append', '10.0.0.0/24', 'proto', 'kernel',
-                                'src', '10.0.0.1', 'dev', 'qr-23380d11-d2'))
-
-    def test_pullup_route_first(self):
-        # NOTE(brian-haley) Currently we do not have any IPv6-specific usecase
-        # for pullup_route, hence skipping. Revisit, if required, in future.
-        if self.ip_version == 6:
-            return
-        # interface is first in the list - no changes
-        output = [DEVICE_ROUTE_SAMPLE, SUBNET_SAMPLE2]
-
-        def pullup_side_effect(self, *args):
-            result = output.pop(0)
-            return result
-
-        self.parent._run = mock.Mock(side_effect=pullup_side_effect)
-        self.route_cmd.pullup_route('tap1d7888a7-10', ip_version=4)
-        # Check two calls - device get and subnet get
-        self.assertEqual(len(self.parent._run.mock_calls), 2)
-
     def test_flush_route_table(self):
         self.route_cmd.flush(self.ip_version, self.table)
         self._assert_sudo([self.ip_version], ('flush', 'table', self.table))
@@ -1217,12 +1168,6 @@ class TestIPRoute(TestIpRouteCommand):
             args = self._remove_dev_args(args)
         super(TestIPRoute, self)._assert_sudo(options, args)
 
-    def test_pullup_route(self):
-        # This method gets the interface name passed to it as an argument.  So,
-        # don't remove it from the expected arguments.
-        self.check_dev_args = True
-        super(TestIPRoute, self).test_pullup_route()
-
     def test_del_gateway_cannot_find_device(self):
         # This test doesn't make sense for this case since dev won't be passed
         pass
@@ -1343,57 +1288,6 @@ class TestDeviceExists(base.BaseTestCase):
             self.assertFalse(ip_lib.ensure_device_is_ready("eth0"))
 
 
-class TestGetRoutingTable(base.BaseTestCase):
-    @mock.patch.object(ip_lib, 'IPWrapper')
-    def _test_get_routing_table(self, version, ip_route_output, expected,
-                                mock_ipwrapper):
-        instance = mock_ipwrapper.return_value
-        mock_netns = instance.netns
-        mock_execute = mock_netns.execute
-        mock_execute.return_value = ip_route_output
-        self.assertEqual(expected, ip_lib.get_routing_table(version))
-
-    def test_get_routing_table_4(self):
-        ip_route_output = ("""
-default via 192.168.3.120 dev wlp3s0  proto static  metric 1024
-10.0.0.0/8 dev tun0  proto static  scope link  metric 1024
-10.0.1.0/8 dev tun1  proto static  scope link  metric 1024 linkdown
-""")
-        expected = [{'destination': 'default',
-                     'nexthop': '192.168.3.120',
-                     'device': 'wlp3s0',
-                     'scope': None},
-                    {'destination': '10.0.0.0/8',
-                     'nexthop': None,
-                     'device': 'tun0',
-                     'scope': 'link'},
-                    {'destination': '10.0.1.0/8',
-                     'nexthop': None,
-                     'device': 'tun1',
-                     'scope': 'link'}]
-        self._test_get_routing_table(4, ip_route_output, expected)
-
-    def test_get_routing_table_6(self):
-        ip_route_output = ("""
-2001:db8:0:f101::/64 dev tap-1  proto kernel  metric 256  pref medium
-2001:db8:0:f102::/64 dev tap-2  proto kernel  metric 256  pref medium linkdown
-default via 2001:db8:0:f101::4 dev tap-1  metric 1024  pref medium
-""")
-        expected = [{'destination': '2001:db8:0:f101::/64',
-                     'nexthop': None,
-                     'device': 'tap-1',
-                     'scope': None},
-                    {'destination': '2001:db8:0:f102::/64',
-                     'nexthop': None,
-                     'device': 'tap-2',
-                     'scope': None},
-                    {'destination': 'default',
-                     'nexthop': '2001:db8:0:f101::4',
-                     'device': 'tap-1',
-                     'scope': None}]
-        self._test_get_routing_table(6, ip_route_output, expected)
-
-
 class TestIpNeighCommand(TestIPCmdBase):
     def setUp(self):
         super(TestIpNeighCommand, self).setUp()
@@ -1447,7 +1341,7 @@ class TestArpPing(TestIPCmdBase):
                       '-w', mock.ANY,
                       address]
         ip_wrapper.netns.execute.assert_any_call(arping_cmd,
-                                                 extra_ok_codes=[1])
+                                                 check_exit_code=True)
 
     @mock.patch('eventlet.spawn_n')
     def test_no_ipv6_addr_notif(self, spawn_n):
@@ -1470,11 +1364,3 @@ class TestAddNamespaceToCmd(base.BaseTestCase):
     def test_add_namespace_to_cmd_without_namespace(self):
         cmd = ['ping', '8.8.8.8']
         self.assertEqual(cmd, ip_lib.add_namespace_to_cmd(cmd, None))
-
-
-class TestSetIpNonlocalBindForHaNamespace(base.BaseTestCase):
-    def test_setting_failure(self):
-        """Make sure message is formatted correctly."""
-        with mock.patch.object(
-                ip_lib, 'set_ip_nonlocal_bind', side_effect=RuntimeError):
-            ip_lib.set_ip_nonlocal_bind_for_namespace('foo')
